pub enum ExpireKind {
Ex,
ExAt,
}
The kind for setting the expire
Ex is for setting the specified expire time, in milliseconds.
’ExAt` is for setting the specified Unix time at which the key will expire, in seconds.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.